pub type KeyPackage<M> = KeyPackage<BluePallas<M>>;Expand description
A FROST(Pallas, Poseidon) keypair, which can be generated either by a trusted dealer or using a DKG.
When using a central dealer, SecretShares are distributed to
participants, who then perform verification, before deriving
KeyPackages, which they store to later use during signing.
Aliased Type
pub struct KeyPackage<M> { /* private fields */ }